@@ -11,7 +11,8 @@ extensions = [
     'sphinx.ext.coverage',
     'sphinx.ext.ifconfig',
     'sphinx.ext.viewcode',
-    'sphinxcontrib.napoleon'
+    'sphinx.ext.napoleon',
+    'sphinx.ext.extlinks',
 ]
 if os.getenv('SPELLCHECK'):
     extensions += 'sphinxcontrib.spelling',
@@ -21,10 +22,17 @@ if os.getenv('SPELLCHECK'):
 source_suffix = '.rst'
 master_doc = 'index'
 project = 'redis-lock'
-year = '2013-2015'
+year = '2013-2016'
 author = 'Ionel Cristian Mărieș'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '2.3.0'
+version = release = '3.0.0'
+
+pygments_style = 'trac'
+templates_path = ['.']
+extlinks = {
+    'issue': ('https://github.com/ionelmc/python-redis-lock/issues/%s', '#'),
+    'pr': ('https://github.com/ionelmc/python-redis-lock/pull/%s', 'PR #'),
+}
 import sphinx_py3doc_enhanced_theme
 html_theme = "sphinx_py3doc_enhanced_theme"
 html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
@@ -32,8 +40,6 @@ html_theme_options = {
     'githuburl': 'https://github.com/ionelmc/python-redis-lock/'
 }
 
-pygments_style = 'trac'
-templates_path = ['.']
 html_use_smartypants = True
 html_last_updated_fmt = '%b %d, %Y'
 html_split_index = True
@@ -41,3 +47,7 @@ html_sidebars = {
    '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
 }
 html_short_title = '%s-%s' % (project, version)
+
+napoleon_use_ivar = True
+napoleon_use_rtype = False
+napoleon_use_param = False
